﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Security.Claims;
using System.Threading.Tasks;
using Aya_Backend.Data;
using Aya_Backend.Data.Repositories.UserRepositories;
using Aya_Backend.Services;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;

namespace Aya_Backend.Controllers
{
    [Authorize]
    [Route("api/[controller]")]
    [ApiController]
    public class UserController : ControllerBase
    {
        private readonly IRepository _context;
        private readonly IUserService _userService;

        public UserController(IRepository context, IUserService userService)
        {
            _context = context;
            _userService = userService;
        }

        //Returns the user object of the user currently logged in (from token passed).
        [Route("get")]
        [HttpGet]
        public async Task<IActionResult> GetUser()
        {
            string userId = User.FindFirst(ClaimTypes.Name)?.Value;
            var user = _context.GetUser(Int32.Parse(userId));

            if (user == null)
                return NotFound();
            return Ok(user);
        }

        //Returns the user object if login credentials are valid (user object includes jwt token).
        [AllowAnonymous]
        [Route("login")]
        [HttpPost]
        public async Task<IActionResult> Login([FromBody] LoginDTO login)
        {
            var user = _userService.Authenticate(login.Username, login.Password);

            if (user == null)
                return BadRequest();

            return Ok(user);
        }

        //Creates a new user object with the credentials passed and authenticates them.
        [AllowAnonymous]
        [Route("create")]
        [HttpPost]
        public async Task<IActionResult> CreateAccount([FromBody] LoginDTO account)
        {
            var user = _context.AddUser(new User() { Username = account.Username, Password = account.Password });

            return Ok(user);
        }
    }
}