﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Security.Claims;
using System.Threading.Tasks;
using Aya_Backend.Data;
using Aya_Backend.Data.Repositories.UserRepositories;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;

namespace Aya_Backend.Controllers
{
    [Authorize]
    [Route("api/[controller]")]
    [ApiController]
    public class WorkpageController : ControllerBase
    {
        private readonly IRepository _context;

        public WorkpageController(IRepository context)
        {
            _context = context;
        }

        //Returns a workpage, aslong as the user is owner.
        [Route("get")]
        [HttpGet]
        public async Task<IActionResult> GetWorkpage(int id)
        {
            string userId = User.FindFirst(ClaimTypes.Name)?.Value;
            int workpageOwner = _context.GetWorkpageOwnerID(id);

            if (workpageOwner != Int32.Parse(userId))
                return BadRequest();

            return Ok(_context.GetWorkpage(id));
        }

        //Returns a list of the workpages from a workbook (given a workbook id).
        //Only returns them if the workbook belongs to the user.
        [Route("fromworkbook")]
        [HttpGet]
        public async Task<IActionResult> GetFromWorkbook(int id)
        {
            string userId = User.FindFirst(ClaimTypes.Name)?.Value;
            var workbook = _context.GetWorkbook(id);

            if (workbook.OwnerID != Int32.Parse(userId))
                return BadRequest();

            return Ok(_context.GetWorkbookWorkpages(id));
        }

        //Adds a workpage with the given name and workbookid, aslong as they are the owner of the workbook.
        [Route("add")]
        [HttpPost]
        public async Task<IActionResult> AddWorkpage(string name, int workbookid)
        {
            string userId = User.FindFirst(ClaimTypes.Name)?.Value;
            var workbook = _context.GetWorkbook(workbookid);

            if (workbook.OwnerID != Int32.Parse(userId))
                return BadRequest();

            var wp = new Workpage() { Name = name, WorkbookID = workbookid, Content = String.Empty };
            _context.AddWorkpage(wp);
            return Ok("true");
        }

        //Updates the content of a workpage from the request body, as long as they are the owner of the workbook.
        [Route("updateworkpagecontent")]
        [HttpPost]
        public async Task<IActionResult> UpdateWorkpageContent(int id, [FromBody] string content)
        {
            string userId = User.FindFirst(ClaimTypes.Name)?.Value;
            var workbook = _context.GetWorkbook(id);

            if (workbook.OwnerID != Int32.Parse(userId))
                return BadRequest();

            _context.UpdateWorkbookContent(id, content);
            return Ok("true");
        }
    }
}